# ngl
A python wrapper for the C++ neighborhood graph library NGL (http://www.ngraph.org/) for computing empty region graphs. Intended to be used with hdtopology library (https://github.com/LLNL/hdtopology) and NDDAV visualization system (https://github.com/LLNL/NDDAV.git).

Released under LLNL-CODE-772013
